
<p align="center">
  <img src="doc/_static/logo/logo.png" alt="recipipe logo" />
</p>

[![GitHub license](https://img.shields.io/github/license/guiferviz/recipipe.svg)](https://github.com/guiferviz/recipipe/blob/master/LICENSE)
[![Build Status](https://travis-ci.org/guiferviz/recipipe.png)](https://travis-ci.org/guiferviz/recipipe)
[![Coverage Status](https://coveralls.io/repos/github/guiferviz/recipipe/badge.svg?branch=master)](https://coveralls.io/github/guiferviz/recipipe?branch=master)
[![Documentation Status](https://readthedocs.org/projects/recipipe/badge/?version=latest)](https://recipipe.readthedocs.io/?badge=latest)
[![Build Docs](https://github.com/guiferviz/recipipe/workflows/Build%20Docs/badge.svg)](https://guiferviz.com/recipipe/)

Improved pipelines for data science projects.


# Getting started

## Install from source

Clone the repository and run:

	pip install .

Install the package in a dev environment with:

    pip install -e .

All the dependencies will be installed automatically.


## Getting started tutorial

Learn how to use Recipipe analyzing data from weird creatures from another planet:
[Recipipe getting started tutorial](examples/paranoids.ipynb).


## Running the tests

Run all the test using:

    pytest

Run an specific test file with:

    pytest tests/<filename>


# License

This project is licensed under the **MIT License**, see the
[LICENSE][license] file for details.


[license]: https://github.com/guiferviz/recipipe/blob/master/LICENSE

